import json

import boto3
from botocore.exceptions import ClientError


def get_data(bucket, key):
    s3 = boto3.resource('s3')
    try:
        obj = s3.Object(bucket, key)
        return obj.get()['Body'].read().decode('utf-8')
    except ClientError:
        return None


def upload_data(bucket, key, data, content_type='application/json'):
    s3 = boto3.resource('s3')
    bucket = s3.Bucket(bucket)
    bucket.put_object(Key=key, Body=data, ContentType=content_type)


def get_json(bucket, key):
    return json.loads(get_data(bucket, key))


def upload_json(bucket, key, data, content_type='application/json'):
    upload_data(bucket, key, json.dumps(data), content_type)



from os import environ
import boto3


def get_client(service, region):
    if 'AWS_PROFILE' in environ:
        session = boto3.Session(profile_name=environ['AWS_PROFILE'])
    else:
        session = boto3.Session()
    return session.client(service, region_name=region)



import setuptools
from piranha.__version__ import __version__

with open("README.md", "r") as fh:
    long_description = fh.read()

version = '.'.join(str(x) for x in __version__)

setuptools.setup(
    name="piranha",
    version=version,
    author="Jens Schaa",
    author_email="jens.schaa@posteo.de",
    description="My most common boto3 use cases",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/redvox/piranha",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 1 - Planning",
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
    ]
)
